California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Prior Elections
NOVEMBER 2, 2004, GENERAL
16 Measures
PROP 1A - SCA 4 (RESOLUTION CHAPTER 133, STATUTES OF 2004). TORLAKSON. PROTECTION OF LOCAL GOVERNMENT REVENUES.
PROP 59 - SCA 1 (RESOLUTION CHAPTER 1, STATUTES OF 2004). BURTON. ACCESS TO GOVERNMENT INFORMATION
PROP 60 - SCA 18 (RESOLUTION CHAPTER 103, 2004). JOHNSON. ELECTION RIGHTS OF POLITICAL PARTIES. SURPLUS PROPERTY. LEGISLATIVE CONSTITUTIONAL AMENDMENT.
PROP 60A - SCA (RESOLUTION CHAPTER 103, 2004). JOHNSON. SURPLUS PROPERTY. LEGISLATIVE CONSTITUTIONAL AMENDMENT.
PROP 61 - CHILDREN'S HOSPITAL PROJECTS. GRANT PROGRAM. BOND ACT. INITIATIVE STATUTE.
PROP 62 - ELECTIONS. PRIMARIES. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROP 63 - MENTAL HEALTH SERVICES EXPANSION AND FUNDING. TAX ON INCOMES OVER $1 MILLION. INITIATIVE STATUTE.
PROP 64 - LIMITATIONS ON ENFORCEMENT OF UNFAIR BUSINESS COMPETITION LAWS. INITIATIVE STATUTE
PROP 65 - LOCAL GOVERNMENT FUNDS AND REVENUES. STATE MANDATES. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROP 66 - LIMITATIONS ON "THREE STRIKES" LAW. SEX CRIMES. PUNISHMENT. INITIATIVE STATUTE.
PROP 67 - EMERGENCY AND MEDICAL SERVICES. FUNDING. TELEPHONE SURCHAGE. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROP 68 - TRIBAL GAMING COMPACT RENEGOTIATION. NON-TRIBAL COMMERCIAL GAMBLING EXPANSION. REVENUES, TAX EXEMPTIONS. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROP 69 - DNA SAMPLES. COLLECTION. DATABASE. FUNDING. INITIATIVE STATUTE.
PROP 70 - TRIBAL GAMING COMPACTS. EXCLUSIVE GAMING RIGHTS. CONTRIBUTIONS TO STATE. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROP 71 - STEM CELL RESEARCH. FUNDING. BONDS. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROP 72 - REFERENDUM PETITION TO OVERTURN AMENDMENTS TO HEALTH CARE COVERAGE REQUIREMENTS.
MARCH 2, 2004, PRIMARY
4 Measures
PROP 55 - KINDERGARTEN-UNIVERSITY PUBLIC EDUCATION FACILITIES BOND ACT OF 2004.
PROP 56 - STATE BUDGET, RELATED TAXES, AND RESERVE. VOTING REQUIREMENTS. PENALTIES. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROP 57 - ABX5 9 (CHAPTER 2, STATUTES 2003, 5TH EXTRAORDINARY SESSION). OROPEZA. ECONOMIC RECOVERY BONDS.
PROP 58 - ABX5 5 (RESOLUTION CHAPTER 1, STATUTES OF 2003, 5TH EXTRAORDINARY SESSION). OROPEZA. STATE FINANCE.
OCTOBER 7, 2003, SPECIAL ELECTION
3 Measures
2003 RECALL QUESTION
PROP 53 - INFRASTRUCTURE: FINANCE.
PROP 54 - CLASSIFICATION BY RACE, ETHNICITY, COLOR OR NATIONAL ORIGIN.